# Examples

| File Name | Short Description | Link |
|---|---|---|
| [dynamic_create_update_delete_deployment.py](./dynamic_create_update_delete/dynamic_create_update_delete_deployment.py) | Pythonic copy of the client-go example | [Documentation](./dynamic_create_update_delete/README.md) |
| [notebook.ipynb](./notebook/notebook.ipynb) | Jupyter Notebook walkthrough of envtest & client | [Documentation](./notebook/README.md) |
| [test_kubernetes.py](./test_kubernetes/test_kubernetes.py) | Pytest example using EnvTest and the [official Kubernetes client](https://github.com/kubernetes-client/python) | [Documentation](./test_kubernetes/README.md) |